local common = require("celediel.DoorRandomizer.common")
local config = require("celediel.DoorRandomizer.config").getConfig()

local function createTableVar(id) return mwse.mcm.createTableVariable({id = id, table = config}) end

local template = mwse.mcm.createTemplate({name = common.modName})
template:saveOnClose(common.configPath, config)

local page = template:createSideBarPage({
    label = "Options principales",
    description = string.format("%s v%s par %s\n\n%s\n\n", common.modName, common.version, common.author, common.modInfo)
})

local category = page:createCategory(common.modName)

category:createYesNoButton({label = "Choisir les cellules des rgions sauvages ?", variable = createTableVar("wildernessCells")})

category:createYesNoButton({
    label = "Choisir uniquement les cellules qui placent le joueur prs d'une porte ?",
    variable = createTableVar("needDoor")
})

category:createDropdown({
    label = "Choisir les intrieurs et/ou extrieurs comme destinations",
    options = {
        {label = "Les deux", value = common.cellTypes.both},
        {label = "Intrieurs uniquement", value = common.cellTypes.interior},
        {label = "Extrieurs uniquement", value = common.cellTypes.exterior},
        {label = "Correspondre  la destination originale", value = common.cellTypes.match}
    },
    defaultSetting = common.cellTypes.both,
    variable = createTableVar("interiorExterior")
})

category:createSlider({
    label = "Chance alatoire ",
    min = 0,
    max = 100,
    step = 1,
    jump = 2,
    variable = createTableVar("randomizeChance")
})

category:createYesNoButton({
    label = "Conserver la destination alatoire ?",
    description = "Les portes conservent leur destination alatoirement choisie, " ..
        "ou retrouvent leur destination d'origine lors du prochain changement de cellule.\n\n" ..
        "Attention ! Cette option altre de faon permanente la destination des portes pour cette sauvegarde." ..
        "Activez  vos risques et prils !",
    variable = createTableVar("keepRandomized")
})

category:createYesNoButton({label = "Ignorer les portes scriptes ?", variable = createTableVar("ignoreScripted")})

category:createYesNoButton({label = "Mode dbug", variable = createTableVar("debug")})

template:createExclusionsPage({
    label = "Cellules ignores",
    description = "Ces cellules ne seront pas prises en considration lors de l'alation des destinations.",
    showAllBlocked = false,
    variable = createTableVar("ignoredCells"),
    filters = {
        {
            label = "Cellules",
            callback = function()
                local cells = {}
                for cell, _ in pairs(tes3.dataHandler.nonDynamicData.cells) do table.insert(cells, cell) end
                return cells
            end
        }
    }
})

template:createExclusionsPage({
    label = "Portes ignores",
    description = "La destination de ces portes ne sera pas rendue alatoire.",
    showAllBlocked = false,
    variable = createTableVar("ignoredDoors"),
    filters = {{label = "Portes", type = "Object", objectType = tes3.objectType.door}}
})

return template
